<!-- Allow HTML -->
<!-- markdownlint-disable MD033 -->

<!-- Allow HTML top-level heading -->
<!-- markdownlint-disable MD041 -->

<a name="readme-top"></a>

<!-- PROJECT SHIELDS -->
<div align="center">

<a href="[pypi-url]">[![PYPI - Version][version-shield]][pypi-url]</a>
<a href="[pypi-url]">[![PYPI - Downloads][downloads-shield]][pypi-url]</a>
<a href="[forks-url]">[![Forks][forks-shield]][forks-url]</a>
<a href="[stars-url]">[![Stargazers][stars-shield]][stars-url]</a>
<a href="[license-url]">[![GPL3.0 License][license-shield]][license-url]</a>

</div>

<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/caffeine-addictt/nexis-client">
    <img src="assets/logo.png" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">Nexis Client</h3>

  <p align="center">
    NYP InfoSec Auth Client
    <br />
    <a href="https://github.com/caffeine-addictt/nexis-client/blob/main/docs">
      <strong>Explore the docs »</strong>
    </a>
    <br />
    <br />
    <a href="https://github.com/caffeine-addictt/nexis-client/issues">Report Bug</a>
    ·
    <a href="https://github.com/caffeine-addictt/nexis-client/issues">Request Feature</a>
  </p>
</div>

<!-- ABOUT THE PROJECT -->

## About The Project

This is the client for NYP InfoSec Auth.

See the [open issues](https://github.com/caffeine-addictt/nexis-client/issues)
for a full list of proposed features (and known issues).

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- GETTING STARTED -->

## Getting Started

This is how you can get `Nexis` running locally.
Follow these simple example steps.

### Prerequisites

- Python 3.9+

### Installation

_Below is an example of how you can install and use Nexis._

#### 1. Install `Nexis`

```sh
pip install nexis
```

#### 2. Run `Nexis`

```sh
nexis --help
```

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- CONTRIBUTING -->

## Contributing

Contributions are what make the open source community
such an amazing place to learn, inspire, and create.
Any contributions you make are **greatly appreciated**. ( ˶ˆᗜˆ˵ )

If you have a suggestion that would make this better,
please fork the repo and create a pull request.
You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

Read our [contributing guide](./CONTRIBUTING.md) for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- LICENSE -->

## License

Distributed under the GPL-3.0 License. See [LICENSE](./LICENSE) for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- CONTACT -->

## Contact

Jun Xiang - [contact@ngjx.org](mailto:contact@ngjx.org)

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- ACKNOWLEDGMENTS -->

## Acknowledgments

- [Repository Template](https://github.com/caffeine-addictt/template)
- [Choose an Open Source License](https://choosealicense.com)
- [GitHub Emoji Cheat Sheet](https://www.webpagefx.com/tools/emoji-cheat-sheet)
- [Malven's Flexbox Cheatsheet](https://flexbox.malven.co/)
- [Malven's Grid Cheatsheet](https://grid.malven.co/)
- [Img Shields](https://shields.io)

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->

[version-shield]: https://img.shields.io/pypi/v/nexis.svg?style=for-the-badge&color=efd0cd
[downloads-shield]: https://img.shields.io/pypi/dm/nexis.svg?style=for-the-badge
[pypi-url]: https://pypi.org/project/nexis/
[forks-shield]: https://img.shields.io/github/forks/caffeine-addictt/nexis-client.svg?style=for-the-badge
[forks-url]: https://github.com/caffeine-addictt/nexis-client/network/members
[stars-shield]: https://img.shields.io/github/stars/caffeine-addictt/nexis-client.svg?style=for-the-badge&color=yellow
[stars-url]: https://github.com/caffeine-addictt/nexis-client/stargazers
[license-shield]: https://img.shields.io/github/license/caffeine-addictt/nexis-client.svg?style=for-the-badge
[license-url]: https://github.com/caffeine-addictt/nexis-client/blob/main/LICENSE
